"""
Aggressive Strategies - Offensive-focused strategy implementations.
"""

from ludo_engine.strategies.aggressive.killer import KillerStrategy
from ludo_engine.strategies.aggressive.optimist import OptimistStrategy

__all__ = ["KillerStrategy", "OptimistStrategy"]
