"""
Special Strategies - Interactive and external AI strategy implementations.
"""

from ludo_engine.strategies.special.human import HumanStrategy
from ludo_engine.strategies.special.llm import LLMStrategy

__all__ = ["HumanStrategy", "LLMStrategy"]
